{% extends "layouts/base.html" %}

{% block title %} Building a cyber secure organisation {% endblock %}

{% block stylesheets %}{% endblock stylesheets %}

{% block content %}
        <div class="page-breadcrumb">
            <div class="row align-items-center">
                <div class="col-md-6 col-8 align-self-center">
                    <h3 class="page-title mb-0 p-0">Building a cyber secure organisation</h3>
                    <div class="d-flex align-items-center">
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb">
                                <li class="breadcrumb-item"><a href="/home">Home</a></li>
                                <li class="breadcrumb-item active"><a href="/content">Security content</a></li>
                                <li class="breadcrumb-item active" aria-current="page">Building a cyber secure organisation</li>
                            </ol>
                        </nav>
                    </div>
                </div>
                {%  include 'includes/component/button__support.html' %}
            </div>
        </div>
        <div class="container-fluid">
            <div class="row">
                <div class="col-12">
                    <div class="card">
                        <div class="card-body">
                            <div id="athena_content">
                                <iframe width="100%"
                                        height="315"
                                        src="https://www.youtube.com/embed/zG12DVyzMsE?si=F5px9c2A1PIijXoX"
                                        title="YouTube video player" frameborder="0"
                                        allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                                        allowfullscreen></iframe>
                                {{ 'content/building_a_cybersecure_organisation' | athena_html_content | safe }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            {% with target='docs/content/2-building-a-cybersecure-organisation.md'%}
                {%  include 'includes/component/edit_this_page.html'%}
            {%  endwith %}
        </div>


{% endblock content %}

{% block javascripts %}{% endblock javascripts %}
