{% extends "layouts/base-fullscreen.html" %}

{% block title %} Error 500 {% endblock %} 

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

    <!-- ============================================================== -->
    <!-- Login box.scss -->
    <!-- ============================================================== -->
    <div class="error-box">
        <div class="error-body text-center">
            <h1 class="error-title">500</h1>
            <h3 class="text-uppercase error-subtitle">
                {{ error }}
            </h3>
            <p class="text-muted mb-4 mt-4">
                Internal Server Error occurred. Please contact the administrator.
            </p>

            <a href="/" class="btn btn-info btn-rounded waves-effect waves-light mb-4 text-white">Back to home</a>

        </div>

    </div>


{% endblock content %}

{% block javascripts %}

{% endblock javascripts %}
