<div class="container py-3 debug_view">
    <form onsubmit="submit_ws_message(event);">
        <div class="row">
            <div class="col-8">
                <div class="mb-3"> <!-- Dropdown for commands -->
                    <label for="command_select" class="form-label">Command:</label>
                    <select id="command_select" class="form-select">
                        <option>Whoami</option>
                        <option>Active Connections</option>
                        <option>Send message</option>
                    </select>
                </div>
                <div class="mb-3"> <!-- Textbox for message -->
                    <label for="message_to_send" class="form-label">Message:</label>
                    <textarea id="message_to_send" name="message_to_send" placeholder="Type your message here..." class="form-control"></textarea>
                </div>
            </div>
            <div class="col-4 d-flex align-items-stretch"> <!-- Send button with 100% height -->
                <button type="submit" class="btn btn-primary w-100 align-self-stretch">Send Message</button>
            </div>
        </div>
    </form>
</div>
