
    <script src="{{ config.ASSETS_ROOT }}/plugins/jquery/dist/jquery.min.js"></script>
    <!-- Bootstrap tether Core JavaScript -->
    <script src="{{ config.ASSETS_ROOT }}/plugins/bootstrap/dist/js/bootstrap.bundle.min.js"></script>
    <script src="{{ config.ASSETS_ROOT }}/js/app-style-switcher.js"></script>
    <!--Wave Effects -->
    <script src="{{ config.ASSETS_ROOT }}/js/waves.js"></script>
    <!--Menu sidebar -->
    <script src="{{ config.ASSETS_ROOT }}/js/sidebarmenu.js"></script>

    <!--Custom JavaScript -->
    <!-- todo: move into TCB CDN -->

    <script type="text/javascript" src= "{{ config.ASSETS_ROOT }}/plugins/data-tables/js/dataTables.min.js"                               ></script>
    <link   type="text/css"        href="{{ config.ASSETS_ROOT }}/plugins/data-tables/css/dataTables.dataTables.min.css" rel="stylesheet" >
