{% extends "layouts/base.html" %}

{% block title %} Security content {% endblock %}

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

        <div class="page-breadcrumb">
            <div class="row align-items-center">
                <div class="col-md-6 col-8 align-self-center">
                    <h3 class="page-title mb-0 p-0">Security content</h3>
                    <div class="d-flex align-items-center">
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb">
                                <li class="breadcrumb-item"><a href="/home">Home</a></li>
                                <li class="breadcrumb-item active"><a href="/content">Security content</a></li>
                            </ol>
                        </nav>
                    </div>
                </div>
                {%  include 'includes/component/button__support.html' %}
            </div>
        </div>
        <div class="container-fluid">

            <div class="row">
                <div class="col-lg-6">
                    <div class="card">
                        <div class="card-body">
                            <h3 class="card-title">Cyber security in the boardroom </h3>
                            <h6 class="card-subtitle">Why it matters</h6>
                            <div id="visitor"  style="height: 290px; width: 100%; max-height: 290px; position: relative;" class="c3">
                                Too many boards see cyber security as an IT concern, not a board-level responsibility. This leads to a lack of understanding between boards and their security teams, as board members feel that technical staff are unable to explain key issues in the context of the strategic aims of the organisation.
                                In turn, security teams think that the board does not have the required knowledge to understand them. Ultimately, boards accept that they need to improve their cyber security governance but lack the required confidence to do so.

                                <br/>
                                <br/>
                                <br/>

                                <div class="col text-center">
                                    <a href="/content/cybersecurity-in-boardroom">
                                        <button class="btn btn-success mx-auto">Read More</button>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-lg-6">
                    <div class="card">
                        <div class="card-body">
                            <h3 class="card-title">Building a cyber secure organisation </h3>
                            <h6 class="card-subtitle">Where to start</h6>
                            <div id="visitor"  style="height: 290px; width: 100%; max-height: 290px; position: relative;" class="c3">
                                Unfortunately, cyber crime is not going away. In 2022 alone, ransomware attacks increased by 1000%. Leaders wanting to build cyber secure organisations should understand that it starts with them. Leaders are required to become visible advocates of an organisation’s cyber strategy.
                                While leaders will want to ensure their organisation is as prepared as they can be, they should also assume will be attacked. Not if, but when. The issue they need to focus on is how their organisation will react when it happens.

                                <br/>
                                <br/>
                                <br/>

                                <div class="col text-center">
                                    <a href="/content/building-a-cybersecure-organisation">
                                        <button class="btn btn-success mx-auto">Read More</button>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <div>

            <div class="row">
                <div class="col-lg-6">
                    <div class="card">
                        <div class="card-body">
                            <h3 class="card-title">Incident management </h3>
                            <h6 class="card-subtitle">Why it matters</h6>
                            <div id="visitor"  style="height: 290px; width: 100%; max-height: 290px; position: relative;" class="c3">
                                <p>
                                    Boards need to be prepared to detect and respond to incidents in order to prevent the attacker from inflicting further damage. Handling an incident effectively whilst in the media spotlight is not easy but it will go a long way to reducing the overall impact on an organisation’s reputation.
                                </p>
                                <p>
                                    An organisation’s incident management framework must ensure that everyone has a clear understanding of their role, especially board members who are likely be representing the organisation in the media. Boards also need to make clear who it is willing to devolve authority to when there is an incident
                                </p>

                                <div class="col text-center">
                                    <a href="/content/incident-management">
                                        <button class="btn btn-success mx-auto">Read More</button>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-lg-6">
                    <div class="card">
                        <div class="card-body">
                            <h3 class="card-title">The importance of digital trust </h3>
                            <h6 class="card-subtitle">Where we are going</h6>
                            <div id="visitor"  style="height: 290px; width: 100%; max-height: 290px; position: relative;" class="c3">
                                When an organisation has a strong cyber security strategy it is also contributing to its growth strategy. That is because a successful cybers ecurity strategy strengthens the digital trust it has with its customers. Digital trust is the confidence users put in people, technology, and processes to provide a digitally secure environment. That confidence needs to be earned and there is no better way to earn it than by demonstrating than an organisation has a strong cyber security strategy.

                                <br/>
                                <br/>
                                <br/>

                                <div class="col text-center">
                                    <a href="/content/importance-of-digital-trust">
                                        <button class="btn btn-success mx-auto">Read More</button>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <div>



        </div>


{% endblock content %}

{% block javascripts %}{% endblock javascripts %}
