{% macro cell_ti_status(ip_data, threat) %}
    {% set threat_value = ip_data.get('threat', {}).get(threat, 'N/A') %}
    {% if threat_value == 'N/A' %}
        N/A
    {% elif threat_value %}
        <span class="label label-danger">True</span>
    {% else %}
        <span class="label label-info">False</span>
    {% endif %}
{% endmacro %}
