
<h1>Logs Streams</h1>
<div id="dev-area"></div>
<p>
    There are {{ user_data.get('active_connections') | length }} active connections
</p>

<style > {% include 'dev/odin/panels/log-streams/log-streams.css'           %} </style>
<script> {% include 'dev/odin/panels/log-streams/log-streams.js'            %} </script>
<script> {% include 'dev/odin/panels/log-streams/log-streams.ws-support.js' %} </script>

{% include 'dev/odin/panels/log-streams/send-ws-message.html' %}
<hr/>

<table id='table-logs' class="table table-striped custom-table-padding">
  <thead id="headers">
    <tr>
        <th>#</th>
        <th>when</th>
        <th>topic</th>
        <th>data</th>
    </tr>
  </thead>
  <tbody id="rows">
        <!-- rows will go here -->
  </tbody>
</table>

