{% extends "layouts/base-fullscreen.html" %}

{% block title %} Logging in... {% endblock %}

{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

    <div id='cbr_logging_you_in' class="error-box">
        <div class="error-body">

            <div class="card col-lg-4 mx-auto">
                <div class="row text-center justify-content-center">
                    <p><img alt="CBR Logo" src="{{ config.ASSETS_ROOT }}/cbr/cbr-logo.jpg" width="90%" ></p>
                </div>
                <div class="card-body profile-card">

                    <div style="text-align: center;">
                        <h3>...logging you in...</h3>
                    </div>


                    <script type="text/javascript">
                        // save the session in the localStorage's user_data variable
                        var user_data = { 'session_id' : "{{ session_id}}" };
                        localStorage.setItem('user_data', JSON.stringify(user_data));

                        setTimeout(function() {
                            window.location.href = "/athena";
                        }, 2000);
                    </script>


                </div>
            </div>

        </div>
        <footer class="footer text-center w-100">
            &copy; Cyber Boardroom - 2023 - {{ config.VERSION }}
        </footer>
    </div>
{% endblock %}

{% block javascripts %}


{% endblock javascripts %}