<div class="page-breadcrumb">
    <div class="row align-items-center">
        <div class="col-md-6 col-8 align-self-center">
            <h3 id='header_login_required' class="page-title mb-0 p-0" style="font-size: 25px;">Login Required</h3>
        </div>
    </div>
</div>

<div class="container-fluid">

        <div class="row">

            <div class="card col-lg-6 mx-auto">
                <div class="row text-center justify-content-center">
{#                    <h4 class="card-title mt-4">#}
{#                        Cyber Boardroom#}
{#                    </h4>#}
                    <p><img alt="CBR Logo" src="{{ config.ASSETS_ROOT }}/cbr/cbr-logo.jpg" width="90%" ></p>
                    <h6 class="card-subtitle mt-2">
                        <p>
                            {% if msg %}
                                <span class="text-danger">{{ msg | safe }}</span>
                            {% else %}
                                Please login or create an account to access Athena (your AI advisor)
                            {% endif %}
                        </p>
                    </h6>

                </div>
                <div class="card-body profile-card">

                    <form method="get" action="/login" class="form-horizontal form-material">

                        <div class="row mt-4">
                            <div class="col text-center">
                                <button type="submit" name="login" class="btn btn-success mx-auto">Login or Create Account</button>
                            </div>
                        </div>

                    </form>

                </div>
                <div class="card-body profile-card">
                    <div class="col text-center">
                        <h6 class="card-subtitle mt-2">
                        <a href="/terms_and_conditions">Terms and Conditions</a>
                    </h6>
                </div>
            </div>

        </div>
    </div>
</div>